# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),

## Unreleased

## [1.2] - 2024-05-09

### Added
- Support for shell autocomplete for `bash`, `zsh` and `powershell`. 

## [1.1] - 2024-04-27

### Changed
- The script is now a proper Python package and is distributed via PyPi


## [1.0] - 2020-10-21
### Added
- Initial release


[1.0]: https://github.com/gershnik/wakeonlan/releases/1.0
[1.1]: https://github.com/gershnik/wakeonlan/releases/1.1
[1.2]: https://github.com/gershnik/wakeonlan/releases/1.2
